const crypto = require('crypto');

/*
  Takes a user-provided password and returns a salted hash of it together with the salt.
*/
exports.hashPassword = (password) => {
  const salt = crypto.randomBytes(16).toString('hex');
  const saltAndPassword = [salt, password].join('$');
  const hash = crypto.pbkdf2Sync(saltAndPassword, salt, 2048, 32, 'sha512').toString('hex');
  return [salt, hash].join('$');
}

/*
  Takes a user-provided password and that user's hashed password (from the database).
  Hashes the user password using the same salt and compares the hashes.
  Returns whether the user password is correct.
*/
exports.verifyHash = (userPassword, saltAndHash) => {
  const salt = saltAndHash.split('$')[0];
  const originalHash = saltAndHash.split('$')[1];
  const saltAndPassword = [salt, userPassword].join('$');
  const hash = crypto.pbkdf2Sync(saltAndPassword, salt, 2048, 32, 'sha512').toString('hex');
  return hash === originalHash;
}

/*
  Takes an 11-digit social number.
  Returns an object with birthdate in MySQL date format and a 5-digit social number.
*/
exports.parseSocialNum = (fullSocialNum) => {
  const currentYear = new Date().getFullYear();
  const currentYearLastDigits = currentYear.toString().substring(2, 4);

  const birthDay = fullSocialNum.substring(0, 2);
  const birthMonth = fullSocialNum.substring(2, 4);
  var   birthYear = fullSocialNum.substring(4, 6); // Two-digit birth year

  // Make birthYear 4 digits.
  // Using the current year, determine whether birth year is in the 1900s or 2000s.
  birthYear = (parseInt(birthYear) < (parseInt(currentYearLastDigits)) ? "20" : "19") + birthYear;

  return {
    birthDate: [birthYear, birthMonth, birthDay].join('-'),
    socialNum: fullSocialNum.substring(6, 11)
  };
}
