/**
@license
Copyright (c) 2018 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/

import { css } from 'lit-element';

export const SharedStyles = css`

  /* GENERAL */

  :host {
    display: block;
    box-sizing: border-box;
  }

  h2 {
    font-size: 36px;
    text-align: center;
    color: var(--tertiary-color);
  }

  ul {
    list-style: none;
  }

  ul, li {
    margin: 0;
    padding: 0;
    border: 0;
    font: inherit;
    vertical-align: baseline;
  }

  p {
    color: var(--text-color);
    text-align: center;
    font-size: 16px;
    line-height: 16px;
  }

  p a:link, a:hover, a:active, a:visited {
    color: var(--tertiary-color);
    text-decoration: none;
  }

  .user-container {
    margin: 10px;
    padding-bottom: 5px;
    display: flex;
    flex-direction: row;
    justify-content: space-between;
    border-bottom: solid 1px black;

  }

  /* PAGE CONTAINERS */

  .page-content-container {
    width: 500px;
    margin: 0 auto;
  }

  .page-wide-content-container {
    width: 100vw;
    margin: 0;
  }

  .dark-background-field {
    display: flex;
    flex-direction: column;
    background: var(--primary-color);
    padding: 24px 0;
    margin-top: 15px;
    margin-bottom: 15px;
  }

  .light-background-field {
    background-color: var(--light-sand-color);
    margin: 0 auto 8px auto;
    border-radius: 13px;
    -moz-border-radius: 13px;
    -webkit-border-radius: 13px;
    border: 1px solid var(--dark-sand-color);
    width: 400px;
    color: var(--text-color);
  }

  .status-container {
    display: flex;
    align-items: flex-start;
  }

  .status-container, .dark-background-field p {
    font-size: 22px;
    line-height: 1.5;
    text-align: initial;
    margin: 0 15px 0 30px;
    color: var(--light-text-color);
  }

  /* BUTTONS & INDICATORS */

  .app-button-container {
    display: flex;
    flex-direction: column;
    align-items: center;
  }

  .app-button {
    text-align: center;
    font-size: 20px;
    text-decoration: none;
    cursor: pointer;
    background-color: var(--light-sand-color);
    padding: 15px 0;
    margin-top: 10px;
    border-radius: 13px;
    -moz-border-radius: 13px;
    -webkit-border-radius: 13px;
    border: 1px solid var(--dark-sand-color);
    width: 400px;
    color: var(--text-color);
  }

  a.app-button:link, a.app-button:hover, a.app-button:active, a.app-button:visited {
    color: var(--text-color);
    text-decoration: none;
  }

  .input-app-button {
    background-color: var(--primary-color);
    color: var(--light-text-color);
    font-size: 18px;
    cursor: pointer;
    padding: 15px 0;
    border-style: none;
    border-radius: 10px;
    -moz-border-radius: 10px;
    -webkit-border-radius: 10px;
    width: 285px;
    display: block;
    margin: 0 auto;
  }

  .add-user-icon {
    background: var(--secondary-color);
  }

  .reject-user-icon {
    background: var(--red-reject-color);
  }

  .add-user-icon, .reject-user-icon {
    border: none;
    margin: 5px;
    display: flex;
    flex-direction: column;
    align-items: center;
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    fill: white;
  }

  .status-0, .status-1, .status-2, .status-3, .status-4 {
    width: 30px;
    height: 30px;
    border-radius: 50%;
    -moz-border-radius: 50%;
    -webkit-border-radius: 50%;
    margin: 2px 10px 0 10px;
    font-size: 20px;
    line-height: 30px;
    text-align: center;
    color: var(--light-text-color);
  }

  .status-0 {
    background: var(--status-0-color);
  }
  .status-1 {
    background: var(--status-1-color);
  }
  .status-2 {
    background: var(--status-2-color);
  }
  .status-3 {
    background: var(--status-3-color);
  }
  .status-4 {
    background: var(--status-4-color);
  }

  .notifications-dot {
    position: relative;
    left: 58px;
    bottom: 52px;
    width: 18px;
    height: 18px;
    border-radius: 50%;
    -moz-border-radius: 50%;
    -webkit-border-radius: 50%;
    font-size: 11px;
    line-height: 19px;
    text-align: center;
    color: var(--light-text-color);
    background: var(--status-3-color);
  }

  .input-eye-icon {
    position: absolute;
    top: 5px;
    left: calc(100% - 30px);
    left: -moz-calc(100% - 30px);
    left: -webkit-calc(100% - 30px);
    fill: var(--secondary-color);
    cursor: pointer;
    width: 30px;
    height: 30px;
    display: flex;
    align-items: center;
    justify-content: center;
  }

  /* FORMS */

  .form-comment {
    margin: 0 18px 10px 18px;
    color: var(--text-color);
    font-size: 14px;
  }

  .form-row {
    display: flex;
    margin: 0 10px;
  }

  .form-input, .form-select {
    display: flex;
    flex-direction: column;
    flex: 1;
    -ms-flex: 1;
    -webkit-flex: 1;
    position: relative;
    margin: 0 6px 10px 6px;
    border-radius: 4px;
    -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
    background-color: white;
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.2), 0 2px 5px 0 rgba(0, 0, 0, 0.19);
    border: 1px solid #f2ffff;
  }

  .form-select {
    appearance: menulist-button;
    -moz-appearance: menulist-button;
    -webkit-appearance: menulist-button;
    width: calc(100% - 12px);
    width: -moz-calc(100% - 12px);
    width: -webkit-calc(100% - 12px);
    height: 35px;
    flex-direction: row;
    color: #555;
    padding-left: 5px;
  }

  .form-input label {
    display: none;
  }

  .form-input input {
    border-style: none;
    height: 40px;
    padding: 0 12px;
    font-size: 15px;
    line-height: 4em;
  }

  .input-notice-container {
    pointer-events: none;
    width: 80%;
    height: 100%;
    position: absolute;
    display: flex;
    flex-direction: column;
    align-self: flex-end;
    align-items: flex-end;
    justify-content: center;
  }

  .input-notice, .input-notice-password {
    padding-right: 8px;
    line-height: 16px;
    color: var(--status-3-color);
    font-size: 13px;
    text-align: right;
    pointer-events: none;
  }

  .input-notice-password {
    padding-right: 32px;
  }

  textarea {
    border-style: none;
    resize: vertical;
    padding: 12px;
    font-family: inherit;
    color: #333;
    font-size: 15px;
  }

  .form-radio {
    margin: 16px 15px 6px 15px;
    color: var(--text-color);
  }

  /* CHECKBOXES */

  /* Customize the label (the container) */
  .checkbox-box {
    display: block;
    position: relative;
    padding-left: 35px;
    margin: 6px 0 12px 7px;
    cursor: pointer;
    font-size: 15px;
    color: #333;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
  }

  /* Hide the browser's default checkbox */
  .checkbox-box input {
    position: absolute;
    opacity: 0;
    cursor: pointer;
    height: 0;
    width: 0;
  }

  /* Create a custom checkbox */
  .checkmark {
    position: absolute;
    top: 0;
    left: 0;
    height: 25px;
    width: 25px;
    background-color: #eee;
  }

  /* When the checkbox is checked, add a blue background */
  .checkbox-box input:checked ~ .checkmark {
    background-color: var(--primary-color);
  }

  /* Create the checkmark/indicator (hidden when not checked) */
  .checkmark:after {
    content: "";
    position: absolute;
    display: none;
  }

  /* Show the checkmark when checked */
  .checkbox-box input:checked ~ .checkmark:after {
    display: block;
  }

  /* Style the checkmark/indicator */
  .checkbox-box .checkmark:after {
    left: 9px;
    top: 5px;
    width: 5px;
    height: 10px;
    border: solid white;
    border-width: 0 3px 3px 0;
    -webkit-transform: rotate(45deg);
    -ms-transform: rotate(45deg);
    transform: rotate(45deg);
  }

  /* RADIO BUTTONS */

  .radio-box {
    background-color: var(--light-sand-color);
    font-size: 15px;
    line-height: 42px;
    display: block;
    position: relative;
    height: 40px;
    padding-left: 40px;
    margin-bottom: 8px;
    cursor: pointer;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    border-radius: 5px;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
  }

  /* Hide the browser's default radio button */
  .radio-box input {
    position: absolute;
    opacity: 0;
    cursor: pointer;
  }

  /* Create a custom radio button */
  .radio-checkmark {
    position: absolute;
    top: 7px;
    left: 7px;
    height: 26px;
    width: 26px;
    background-color: var(--medium-sand-color);
    border-radius: 50%;
    -moz-border-radius: 50%;
    -webkit-border-radius: 50%;
    box-sizing: border-box;
  }

  /* On mouse-over, add a darker background color */
  .radio-box:hover input ~ .radio-checkmark {
    background-color: var(--dark-sand-color);
  }

  /* When the radio button is checked, add a blue background */
  .radio-box input:checked ~ .radio-checkmark {
    border: 1px solid var(--secondary-color);
    background-color: white;
  }

  /* Create the indicator (the dot/circle - hidden when not checked) */
  .radio-checkmark:after {
    content: "";
    position: absolute;
    display: none;
  }

  /* Show the indicator (dot/circle) when checked */
  .radio-box input:checked ~ .radio-checkmark:after {
    display: block;
  }

  /* Style the indicator (dot/circle) */
  .radio-box .radio-checkmark:after {
   	top: 5px;
  	left: 5px;
  	width: 14px;
  	height: 14px;
  	border-radius: 50%;
    -moz-border-radius: 50%;
    -webkit-border-radius: 50%;
  	background: var(--secondary-color);
  }

  /* MEDIA QUERIES */

  @media (max-width: 479px) {
    h2 {
      font-size: 24px;
    }

    .form-comment {
      margin-left: 33px;
      margin-right: 33px;
    }

    .form-row {
      display: block;
      margin-left: 25px;
      margin-right: 25px;
    }

    .form-radio {
      margin-left: 30px;
      margin-right: 30px;
    }

    .page-content-container {
      width: 100vw;
    }

    .dark-background-field {
      margin-top: 0;
      padding-top: 5px;
    }

    .app-button {
      width: 85vw;
    }

    .light-background-field {
      width: 90vw;
    }

    .input-app-button {
      width: calc(100vw - 60px);
      width: -moz-calc(100vw - 60px);
      width: -webkit-calc(100vw - 60px);
    }
  }
`;
