import { LitElement, html } from 'lit-element';
import { SharedStyles } from './shared-styles.js';

import { connect } from 'pwa-helpers/connect-mixin.js';
import { store } from '../store.js';
import { appurl } from '../helpers/url.js';
import { fixDrawerPosition } from '../helpers/position-fix.js';
import { fetchResource } from '../actions/server-fetch.js';

/*
  Homepage for athletes. Displays profile information and presents buttons to
  perform key actions.
  Designed for narrow screens, but works fine on wide screens too.
*/
class UserProfile extends connect(store)(LitElement) {
  static get properties() {
    return {
      _drawerOpened: { type: Boolean },
      userID: { type: Number },
      user: { type: Object }
    };
  }

  static get styles() {
    return [
      SharedStyles
    ];
  }

  constructor() {
    super();
    this.user = {};
  }

  render() {
    fixDrawerPosition(this);
    return html`
      <div id="page" class="page-content-container">
        <div class="dark-background-field">
          <p>${this.user.first_name} ${this.user.last_name}</p>
          <p>${this.user.team}</p>
          <p>${this.user.position} ${this.user.shirt_no}</p>
          <div class="status-container">
            Status:
            <span class="status-${this.user.status}"></span>
            ${this.user.summary}
          </div>
        </div>
        <div class="app-button-container">
          <a class="app-button" href="/registrerskade">Registrer skade</a>
          <a class="app-button" href="/mineskader">Mine skader</a>
          <a class="app-button" href="/meldinger">Meldinger</a>
        </div>
      </div>
    `
  }

  stateChanged(state) {
    this._drawerOpened = state.app.drawerOpened;
  }

  firstUpdated() {
    const url = appurl + "/api/users/ath/" + this.userID;
    const fetchOptions = {
      method: "GET"
    };

    store.dispatch(fetchResource(url, fetchOptions)).then(() => {
      const user = store.getState().resources.data.user;
      this.user = user;
    });
  }
}

window.customElements.define('user-profile', UserProfile);
