import { ADD_ATHLETE, ADD_INJURY, ADD_MESSAGE, NEW_INCOMING_MESSAGE, READ_MESSAGES_IN_ATHLETE, READ_MESSAGES_IN_INJURY } from '../actions/inbox.js';
import { LOGOUT } from '../actions/session.js';

const INITIAL_STATE = {
  newMessages: 0,
  unreadInjuries: {},
  unreadAthletes: {},
  athletes: {},
  injuries: {},
  messages: {}
};

const inbox = (state = INITIAL_STATE, action) => {
  switch(action.type){
    case ADD_ATHLETE:
      return {
        ...state,
        athletes: athletes(state.athletes, action)
      };
    case ADD_INJURY:
      return {
        ...state,
        injuries: injuries(state.injuries, action)
      };
    case ADD_MESSAGE:
      if(action.message.injury){
        return {
          ...state,
          injuries: injuries(state.injuries, action),
          messages: messages(state.messages, action)
        };
      } else {
        return {
          ...state,
          athletes: athletes(state.athletes, action),
          messages: messages(state.messages, action)
        };
      }
    case LOGOUT:
      return {
        athletes: INITIAL_STATE.athletes,
        injuries: INITIAL_STATE.injuries,
        messages: INITIAL_STATE.messages,
        unreadInjuries: INITIAL_STATE.unreadInjuries,
        unreadAthletes: INITIAL_STATE.unreadAthletes,
        newMessages: INITIAL_STATE.newMessages
      };
    case READ_MESSAGES_IN_ATHLETE:
      // check if there are any unread messages in athletes injuries. If there is, only count down on newMessages!!
        if(unreadMessagesInInjuries(state.athletes[action.inbox], state.unreadInjuries) == 0) { // There are no new messages in any of this athletes injuries.
          return {
            ...state,
            newMessages: newMessageCount(state.newMessages, action),
            unreadAthletes: unreadInboxes(state.unreadAthletes, action, action.inbox)
          };
        } else { // There are unread messages in this athletes injuries. (The athlete should still have fontWeight=bold)
          return {
            ...state,
            newMessages: newMessageCount(state.newMessages, action)
          };
        }
    case READ_MESSAGES_IN_INJURY:
      // remove unreadmessages in athlete who ownes this injury also, if there are no more unread injuries in this athlete
      const athleteInboxId = Object.keys(state.athletes).filter(key => (Object.keys(state.athletes[key].injuries).filter(i => i == action.inbox)).length > 0);
      const unreadMessagesInj = unreadMessagesInInjuries(state.athletes[athleteInboxId[0]], state.unreadInjuries);
      if(unreadMessagesInj[0] == 0 || (unreadMessagesInj.length == 1 && Number(unreadMessagesInj[0]) == action.inbox)){ // if only one unreadMessage, and that message is in fact the action.inbox (injury)
        return {
          ...state,
          newMessages: newMessageCount(state.newMessages, action),
          unreadAthletes: unreadInboxes(state.unreadAthletes, action, Number(athleteInboxId[0])),
          unreadInjuries: unreadInboxes(state.unreadInjuries, action, action.inbox)
        };
      } else { // There are other unread injuries for this athlete. Remove only the unread injury
        return {
          ...state,
          newMessages: newMessageCount(state.newMessages, action),
          unreadInjuries: unreadInboxes(state.unreadInjuries, action, action.inbox)
        };
      }



    case NEW_INCOMING_MESSAGE:
      const athleteInbox = Object.keys(state.athletes).filter(key => messageIsInInbox(action.messageId, state.athletes[key].messages) > 0);
      const injuryInbox = Object.keys(state.injuries).filter(key => messageIsInInbox(action.messageId, state.injuries[key].messages) > 0);
      if(Number(athleteInbox[0]) > 0){
        return {
          ...state,
          newMessages: newMessageCount(state.newMessages, action),
          unreadAthletes: unreadInboxes(state.unreadAthletes, action, athleteInbox[0])
        };
      } else {
        const athleteInboxId = Object.keys(state.athletes)
                                     .filter(key => (Object.keys(state.athletes[key].injuries)
                                                           .filter(i => i == injuryInbox[0])).length > 0);
        return {
          ...state,
          newMessages: newMessageCount(state.newMessages, action),
          unreadInjuries: unreadInboxes(state.unreadInjuries, action, injuryInbox[0]),
          unreadAthletes: unreadInboxes(state.unreadAthletes, action, athleteInboxId[0])
        };
      }

    default:
      return state;
  }
};

const newMessageCount = (state, action) => {
  switch(action.type){
    case NEW_INCOMING_MESSAGE:
      return state + 1;
    case READ_MESSAGES_IN_ATHLETE:
    case READ_MESSAGES_IN_INJURY:
      return state - 1;
    default:
      return state;
  }

};

const unreadInboxes = (state, action, inboxId) => {
  switch(action.type){
    case NEW_INCOMING_MESSAGE:
      return {
        ...state,
        [inboxId]: "bold"
      };
    case READ_MESSAGES_IN_ATHLETE:
    case READ_MESSAGES_IN_INJURY:
      const newState = { ...state};
      delete newState[inboxId];
      return newState;
    default:
      return state;
  }
};

const athletes = (state, action) => {
  switch (action.type) {
    case ADD_ATHLETE:
      const athleteId = action.athlete.user_id;
      return {
        ...state,
        [athleteId]: action.athlete
      };
    case ADD_MESSAGE:
      const athleteInboxId = action.message.athlete;
      return {
        ...state,
        [athleteInboxId]: athlete(state[athleteInboxId], action)
      }
    default:
      return state;
  }
};

const injuries = (state, action) => {
  switch (action.type) {
    case ADD_INJURY:
      const newInjuryId = action.injury.injury_id;
      return {
        ...state,
        [newInjuryId]: action.injury
      };
    case ADD_MESSAGE:
      const injuryId = action.message.injury;
      return {
        ...state,
        [injuryId]: injury(state[injuryId], action)
      };
    default:
      return state;
  }
};

const athlete = (state, action) => {
  switch (action.type) {
    case ADD_MESSAGE:
      const messageId = action.message.id;
      return {
        ...state,
        messages: messageInInbox(state.messages, action)
      };
    default:
      return state;
  }
};

const injury = (state, action) => {
  switch (action.type) {
    case ADD_MESSAGE:
      const messageId = action.message.id;
      return {
        ...state,
        messages: messageInInbox(state.messages, action)
      };
    default:
      return state;
  }
};

const messageInInbox = (state, action) => {
  switch (action.type) {
    case ADD_MESSAGE:
      const messageId = action.message.id;
      return {
        ...state,
        [messageId]: action.message.id
      };
    default:
      return state;
  }
};

const messages = (state, action) => {
  switch (action.type) {
    case ADD_MESSAGE:
      const messageId = action.message.id;
      return {
        ...state,
        [messageId]: action.message
      };
    default:
      return state;
  }
};

// Help function to check if a message is in an inbox
const messageIsInInbox = (messageId, messages) => {
  if(typeof messages !== 'undefined' && messages !== null){
    const inboxIds = Object.keys(messages);
    if(inboxIds.length > 0){
      const id = inboxIds.filter(i => i == messageId);
      if(id.length > 0){
        return id[0];
      } else {
        return 0;
      }
    } else {
      return 0;
    }
  } else {
    return 0;
  }
};

// Help function to check if there are any new messages in an athlets injuries
// Parameter state: athlete object
// If no unread messages: returns 0.
// If there are unread messages: return array with ids of injuries with unread messages.
const unreadMessagesInInjuries = (athlete, unreadInj) => {
  const injArray = Object.keys(athlete.injuries).filter(inj => inj !== 0);
  const injuriesWithUnreadMessages = injArray.filter(inj => Object.keys(unreadInj).filter(u => u == inj).length > 0);
  if(injuriesWithUnreadMessages.length == 0) {
    return [0];
  } else {
    return injuriesWithUnreadMessages;
  }
};

export default inbox;
