import { ADD_INJURY, ADD_ALL_INJURIES, UPDATE_TITLE, ARCHIVE_INJURY, UNARCHIVE_INJURY } from '../actions/injuries.js';
import { LOGOUT } from '../actions/session.js';

const INITIAL_STATE = {
  injuries_active: [],
  injuries_archived: []
};

const injuries = (state = INITIAL_STATE, action) => {
  switch(action.type){
    case ADD_INJURY:
      return {
        injuries_active: [
          ...state.injuries_active, action.injury
        ]
      };
    case ADD_ALL_INJURIES:
      return {
        injuries_active: action.injuries_active,
        injuries_archived: action.injuries_archived
      };
    case UPDATE_TITLE:
    if (action.injury.archived) {
      return {
        ...state,
        injuries_archived: state.injuries_archived.map((item, index) => {
          if(item.id === action.injury.id) {
            return { ...item, title: action.injury.title }
          }
          return item;
        })
      }
    } else {
      return {
        ...state,
        injuries_active: state.injuries_active.map((item, index) => {
          if(item.id === action.injury.id) {
            return { ...item, title: action.injury.title }
          }
          return item;
        })
      }
    };
    case ARCHIVE_INJURY:
      action.injury.archived = 1;
      return {
        ...state,
        injuries_active: state.injuries_active.filter(element => element.id !== action.injury.id),  // remove from active
        injuries_archived: [ action.injury, ...state.injuries_archived ]  // add to archived
      };
    case UNARCHIVE_INJURY:
      action.injury.archived = 0;
      return {
        ...state,
        injuries_active: [ action.injury, ...state.injuries_active ],  // add to active
        injuries_archived: state.injuries_archived.filter(element => element.id !== action.injury.id)  // remove from archived
      };
    case LOGOUT:  // Flush injuries on logout
      return {
        ...state,
        injuries_active: INITIAL_STATE.injuries_active,
        injuries_archived: INITIAL_STATE.injuries_archived
      };
    default:
      return state;
  }
};

export default injuries;
